********************************************************************
*                                                                  *
* Program name: MARSCOMP.TST  for OS/390                           *
*                                                                  *
* Description: Sample CSQUTIL command file that defines sample     *
*              queues and channels used to verify a connection     *
*              between two queue managers                          *
*                                                                  *
* Statement:     Licensed Materials - Property of IBM              *
*                                                                  *
*                                                                  *
*                5622-960 (C) Copyright IBM Corp. 1995, 1996       *
*                                                                  *
*                U.S. Government Users Restricted Rights - use,    *
*                duplication or disclosure restricted by GSA ADP   *
*                Schedule Contract with IBM Corp.                  *
*                                                                  *
*                                                                  *
********************************************************************
*                                                                  *
* Function:                                                        *
*                                                                  *
*                                                                  *
*   MARSCOMP.TST is a sample CSQUTIL command file that creates     *
*   sample queues and channels used to verify a connection between *
*   two queue managers.                                            *
*                                                                  *
*   The definitions assume that the two queue managers are called  *
*   MARS and VNUS.                                                 *
*                                                                  *
*   Use this sample as input to program CSQUTIL.                   *
*                                                                  *
********************************************************************

* Define a local transmission queue - messages will be put here
* before being sent to the remote queue manager.
* Note that transmission queues cannot be shared between active
* channels - each active channel must have its own transmission
* queue.
DEFINE QLOCAL('SAMPLE.MARS.XMIT') REPLACE +
       DESCR('Local transmission queue')  +
       USAGE(XMITQ)


* Define the remote queue.
* The sample application should put messages on this queue.
DEFINE QREMOTE('SAMPLE.MARS.REMOTE') REPLACE  +
       DESCR('Remote queue defined on MARS') +
       DEFPSIST(YES) +
* This is the name of the local queue on the remote machine.
       RNAME('SAMPLE.VNUS.LOCAL') +
* This is the name of the queue manager on the remote machine.
       RQMNAME('VNUS') +
* This is the name of the local transmission queue to be used.
       XMITQ('SAMPLE.MARS.XMIT')


* Define the channel that will remove messages from the transmission
* queue SAMPLE.MARS.XMIT and send them to the machine specified
* by CONNAME.
*
* Change CONNAME to the TCP/IP name of the machine where
* the remote queue manager is running.
*
DEFINE CHANNEL ('MARS.TO.VNUS')  CHLTYPE(SDR) TRPTYPE(TCP) +
       XMITQ('SAMPLE.MARS.XMIT') +
       CONNAME('VNUS TCP/IP machine name(listener port number)') +
       SENDEXIT('MQC#SND')    +
       SENDDATA('LOG:0 STAT:0 HDR:16 COMP:3') + 
       DESCR('Sender channel for messages to queue manager VNUS') +
       REPLACE


* Define the channel that will accept messages from the remote
* queue manager on the machine specified by CONNAME.
*
* Change CONNAME to the TCP/IP name of the machine where
* the remote queue manager is running.
*
DEFINE CHANNEL ('VNUS.TO.MARS') CHLTYPE(RQSTR) TRPTYPE(TCP) +
       CONNAME('VNUS TCP/IP machine name(listener port number)') +
       RCVEXIT('MQC#RCV')      +
       RCVDATA('LOG:0 STAT:0 HDR:16 COMP:3') + 
       DESCR('Requester channel for messages from queue manager VNUS') +
       REPLACE


* Define the local queue where the remote machine will place
* its messages.
* The sample application should get messages from this queue.
DEFINE QLOCAL('SAMPLE.MARS.LOCAL') REPLACE +
       DESCR('Local queue') +
       DEFPSIST(YES)  +
       SHARE

