********************************************************************
*                                                                  *
* Program name: VNUSCOMP.TST  for OS/390                           *
*                                                                  *
* Description: Sample CSQUTIL command file that defines sample     *
*              queues and channels used to verify a connection     *
*              between two queue managers                          *
*                                                                  *
* Statement:     Licensed Materials - Property of IBM              *
*                                                                  *
*                                                                  *
*                5622-960 (C) Copyright IBM Corp. 1995, 1996       *
*                                                                  *
*                U.S. Government Users Restricted Rights - use,    *
*                duplication or disclosure restricted by GSA ADP   *
*                Schedule Contract with IBM Corp.                  *
*                                                                  *
*                                                                  *
********************************************************************
*                                                                  *
* Function:                                                        *
*                                                                  *
*                                                                  *
*   VNUSCOMP.TST is a sample CSQUTIL command file that creates     *
*   sample queues and channels used to verify a connection between *
*   two queue managers.                                            *
*                                                                  *
*   The definitions assume that the two queue managers are called  *
*   MARS and VNUS.                                                 *
*                                                                  *
*   Use this sample as input to program CSQUTIL.                   *
*                                                                  *
********************************************************************

* Define a local transmission queue - messages will be put here
* before being sent to the remote queue manager.
DEFINE QLOCAL('SAMPLE.VNUS.XMIT') REPLACE +
       DESCR('Local transmission queue')  +
       USAGE(XMITQ)


* Define the remote queue.
* The sample application should put messages on to this queue.
DEFINE QREMOTE('SAMPLE.VNUS.REMOTE') REPLACE  +
       DESCR('Remote queue defined on VNUS') +
       DEFPSIST(YES) +
* This is the name of the local queue on the remote machine.
       RNAME('SAMPLE.MARS.LOCAL') +
* This is the name of the queue manager on the remote machine.
       RQMNAME('MARS') +
* This is the name of the local transmission queue to be used.
       XMITQ('SAMPLE.VNUS.XMIT')


* Define the channel that will remove messages from the transmission
* queue SAMPLE.VNUS.XMIT and send them to the remote queue
* manager.
DEFINE CHANNEL ('VNUS.TO.MARS') CHLTYPE(SVR) TRPTYPE(TCP) +
       XMITQ('SAMPLE.VNUS.XMIT') +
       SENDEXIT('MQC#SND')       +
       SENDDATA('LOG:0 STAT:0 HDR:16 COMP:3') + 
       DESCR('Server channel for messages to queue manager MARS') +
       REPLACE


* Define the channel that will accept messages from the remote
* queue manager.
DEFINE CHANNEL ('MARS.TO.VNUS')  CHLTYPE(RCVR) TRPTYPE(TCP) +
       RCVEXIT('MQC#RCV')      +
       RCVDATA('LOG:0 STAT:0 HDR:16 COMP:3') + 
       DESCR('Receiver channel for messages from queue manager MARS') +
       REPLACE


* Define the local queue where the remote machine will place
* its messages.
* The sample application should get messages from this queue.
DEFINE QLOCAL('SAMPLE.VNUS.LOCAL') REPLACE +
       DESCR('Local queue') +
       DEFPSIST(YES)  +
       SHARE

